@@ -244,7 +244,43 @@ def subset_reads(name, sam_content, qnames_by_name):
 ###############################################################################
 
 
-def output_bam(TEMPDIR, RESULT_SAMPLE, SAMPLE_NAME, GENOME, GENOME_COODINATES, CHROME_SIZE, THREADS):
+def output_bam_control(TEMPDIR, CONTROL_NAME, GENOME, GENOME_COODINATES, CHROME_SIZE, THREADS):
+    randomnum = random.randint(100_000, 999_999)
+
+    path_sam = Path(TEMPDIR, "sam", f"{CONTROL_NAME}_control.sam")
+    sam = midsv.read_sam(path_sam)
+
+    sam_update = deepcopy(sam)
+    sam_update = remove_overlapped_reads(sam_update)
+    sam_update = remove_microhomology(sam_update)
+
+    if GENOME:
+        sam_update = realign(sam_update, GENOME_COODINATES, CHROME_SIZE)
+
+    path_sam_update = Path(TEMPDIR, "report", "bam", f"tmp{randomnum}_{CONTROL_NAME}_control.sam")
+    write_sam(sam_update, path_sam_update)
+
+    path_bam = Path(TEMPDIR, "report", "bam", f"{CONTROL_NAME}.bam")
+    pysam.sort("-@", f"{THREADS}", "-o", str(path_bam), str(path_sam_update))
+    pysam.index("-@", f"{THREADS}", str(path_bam))
+
+    # igvjs
+    sam_headers = [s for s in sam_update if s[0].startswith("@")]
+    sam_contents = [s for s in sam_update if not s[0].startswith("@")]
+    qnames = [s[0] for s in sam_contents[:10000]]
+    qnames = set(list(set(qnames))[:100])
+    sam_subset = [s for s in sam_update if s[0] in qnames]
+    path_bam = Path(TEMPDIR, "report", ".igvjs", f"{CONTROL_NAME}.bam")
+    write_sam(sam_headers + sam_subset, path_sam)
+    pysam.sort("-@", f"{THREADS}", "-o", str(path_bam), str(path_sam))
+    pysam.index("-@", f"{THREADS}", str(path_bam))
+
+    # Remove temporary files
+    sam_temp = Path(TEMPDIR, "report", "bam").glob(f"tmp{randomnum}*.sam")
+    [s.unlink() for s in sam_temp]
+
+
+def output_bam_sample(TEMPDIR, RESULT_SAMPLE, SAMPLE_NAME, GENOME, GENOME_COODINATES, CHROME_SIZE, THREADS):
     randomnum = random.randint(100_000, 999_999)
     path_sam = Path(TEMPDIR, "sam", f"{SAMPLE_NAME}_control.sam")
     sam = midsv.read_sam(path_sam)
@@ -253,12 +289,11 @@ def output_bam(TEMPDIR, RESULT_SAMPLE, SAMPLE_NAME, GENOME, GENOME_COODINATES, C
     sam_update = remove_overlapped_reads(sam_update)
     sam_update = remove_microhomology(sam_update)
 
-    path_sam_update = Path(TEMPDIR, "report", "bam", f"tmp{randomnum}_{SAMPLE_NAME}_control.sam")
     if GENOME:
         sam_update = realign(sam_update, GENOME_COODINATES, CHROME_SIZE)
-        write_sam(sam_update, path_sam_update)
-    else:
-        write_sam(sam_update, path_sam_update)
+
+    path_sam_update = Path(TEMPDIR, "report", "bam", f"tmp{randomnum}_{SAMPLE_NAME}_control.sam")
+    write_sam(sam_update, path_sam_update)
 
     path_bam = Path(TEMPDIR, "report", "bam", f"{SAMPLE_NAME}.bam")
     pysam.sort("-@", f"{THREADS}", "-o", str(path_bam), str(path_sam_update))
