@@ -3,13 +3,20 @@ from werkzeug.utils import secure_filename
 import webbrowser
 from threading import Timer
 from waitress import serve
+import socket
+from contextlib import closing
 from pathlib import Path
 import pandas as pd
+import http.server
+import socketserver
 from . import batch
 
 
-def open_browser():
-    webbrowser.open_new("http://127.0.0.1:2000/")
+def find_free_port():
+    with closing(socket.socket(socket.AF_INET, socket.SOCK_STREAM)) as s:
+        s.bind(("", 0))
+        s.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
+        return s.getsockname()[1]
 
 
 def upload_files(files):
@@ -31,12 +38,6 @@ app = Flask(__name__)
 
 @app.route("/")
 def root_page():
-    #! DEGUB -----------------------------------------------
-    import os
-
-    print(f"DEBUG in gui.py: {__file__}")
-    print(f"DEBUG in gui.py: {os.listdir()}")
-    #! DEGUB -----------------------------------------------
     return render_template("index.html")
 
 
@@ -89,8 +90,18 @@ def submit():
     """
 
 
+def open_browser():
+    webbrowser.open_new("http://127.0.0.1:2000/")
+
+
 def execute():
-    print("Assess 'http://127.0.0.1:2000/' if browser does not automatically open.")
-    Timer(1, open_browser).start()
-    serve(app, host="0.0.0.0", port=2000)
+    PORT = find_free_port()
+    Handler = http.server.SimpleHTTPRequestHandler
+    with socketserver.TCPServer(("", PORT), Handler) as httpd:
+        print(f"serving at port: http://127.0.0.1:{PORT}")
+        httpd.serve_forever()
+        webbrowser.open(f"http://127.0.0.1:{PORT}", autoraise=True)
+    # print("Assess 'http://127.0.0.1:2000/' if browser does not automatically open.")
+    # Timer(1, open_browser).start()
+    # serve(app, host="0.0.0.0", port=2000)
 
